# -*- coding: utf-8 -*-
"""
################################################################################
# Copyright (c) 2010, Ilgar Mashayev
# 
# E-mail: pyzimbra@lab.az
# Website: http://github.com/ilgarm/pyzimbra
################################################################################
# This file is part of pyzimbra.
# 
# Pyzimbra is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# 
# Pyzimbra is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
# 
# You should have received a copy of the GNU Lesser General Public License
# along with Pyzimbra.  If not, see <http://www.gnu.org/licenses/>.
################################################################################

@author: ilgar
"""

CONTEXT = 'context'

AuthRequest = 'AuthRequest'
AuthResponse = 'AuthResponse'
ChangePasswordRequest = 'ChangePasswordRequest'
ChangePasswordResponse = 'ChangePasswordResponse'
GetAccountRequest = 'GetAccountRequest'
GetAccountResponse = 'GetAccountResponse'
GetAccountInfoRequest = 'GetAccountInfoRequest'
GetAccountInfoResponse = 'GetAccountInfoResponse'
GetInfoRequest = 'GetInfoRequest'
GetInfoResponse = 'GetInfoResponse'

E_AUTH_TOKEN = 'authToken'
E_SESSION_ID = 'sessionId'
E_ACCOUNT = 'account'
E_PREAUTH = 'preauth'
E_PASSWORD = 'password'
E_OLD_PASSWORD = 'oldPassword'
E_NAME = 'name'

A_BY = 'by'
A_EXPIRES = 'expires'
A_ID = 'id'
A_SECTIONS = 'sections'
A_TIMESTAMP = 'timestamp'

V_ID = 'id'
V_NAME = 'name'
V_MBOX = 'mbox'
